@@ -70,6 +70,7 @@ class Location(BaseDictKey):
     representation: str
     card: str
     coherenceGraph: str
+    artifactArchivalCopy: str
 
     @staticmethod
     def gql_fragment():
@@ -79,6 +80,7 @@ class Location(BaseDictKey):
               artifact
               card
               coherenceGraph
+              artifactArchivalCopy
             }
             """
 
