@@ -312,3 +312,20 @@ class SetArchivalCopyUrlInput(BaseDictKey):
         if parse_res.scheme not in ['http', 'https']:
             errors.append('URL is invalid')
         return errors
+
+
+@dataclass
+class ExtractFragmentsInput(BaseDictKey):
+    cid: str
+    callback: CallbackInput
+    features: List[str]
+
+    def validate(self):
+        errors = []
+        if not self.cid:
+            errors.append('cid is required')
+        elif not validate_cid(self.cid):
+            errors.append('Invalid cid format. Must be 20.500.12592/abcdef')
+        elif not self.features:
+            errors.append('Invalid features param. You need to specify at least one feature to extract.')
+        return errors
